@@ -81,7 +81,7 @@ class Hypervisor(object):
 		if self.__info["virtype"]:
 			return self.__info["virtype"]
 
-		if self.hypervisor in ("Qemu", "KVM", "VirtualBox", "VMWare"):
+		if self.vendor in ("Qemu", "KVM", "VirtualBox", "VMWare"):
 			return "full"
 
 		return "unknown"
